@@ -9,7 +9,7 @@
 #
 package Reindeer;
 {
-  $Reindeer::VERSION = '0.002';
+  $Reindeer::VERSION = '0.003';
 }
 
 # ABSTRACT: Moose with more antlers
@@ -19,10 +19,13 @@ use warnings;
 
 use Reindeer::Util;
 use Moose::Exporter;
+use Class::Load;
 
 my (undef, undef, $init_meta) = Moose::Exporter->build_import_methods(
     install => [ qw{ import unimport }                ],
     also    => [ 'Moose', Reindeer::Util::also_list() ],
+
+    trait_aliases => [ Reindeer::Util::trait_aliases() ],
 );
 
 sub init_meta {
@@ -52,13 +55,20 @@ Reindeer - Moose with more antlers
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
     # ta-da!
     use Reindeer;
 
+    # ...is the same as:
+    use Moose;
+    use MooseX::MarkAsMethods autoclean => 1;
+    use MooseX::AlwaysCoerce;
+    use MooseX::AttributeShortcuts;
+    # etc, etc, etc
+
 =head1 DESCRIPTION
 
 Like L<Moose>?  Use MooseX::* extensions?  Maybe some L<MooseX::Types>
@@ -69,6 +79,46 @@ a number of the more useful/popular extensions already applied.  Reindeer is a
 drop-in replacement for your "use Moose" line, that behaves in the exact same
 way... Just with more pointy antlers.
 
+=head1 AVAILABLE ATTRIBUTE TRAITS
+
+We make available the following trait aliases.  These traits are NOT
+automatically applied to attributes, and can be used as:
+
+    has foo => (traits => [ AutoDestruct ], ...);
+
+=head2 AutoDestruct
+
+    has foo => (
+        traits  => [ AutoDestruct ],
+        is      => 'ro',
+        lazy    => 1,
+        builder => 1,
+        ttl     => 600,
+    );
+
+Allows for a "ttl" attribute option; this is the length of time (in seconds)
+that a stored value is allowed to live; after that time the value is cleared
+and the value rebuilt (given that the attribute is lazy and has a builder
+defined).
+
+See L<MooseX::AutoDestruct> for more information.
+
+=head2 MultiInitArg
+
+has 'data' => (
+    traits    => [ MultiInitArg ],
+    is        => 'ro',
+    isa       => 'Str',
+    init_args => [qw(munge frobnicate)],
+);
+
+This trait allows your attribute to be initialized with any one of multiple
+arguments to new().
+
+See L<MooseX::MultiInitArg> for more information.
+
+=head2 UndefTolerant
+
 =head1 INCLUDED EXTENSIONS
 
 Reindeer includes the traits and sugar provided by the following extensions.
@@ -101,6 +151,12 @@ marked as methods, and L<namespace::autoclean> invoked.
 
 Non-Moose specific items made available to your class/role:
 
+=head2 L<namespace::autoclean>
+
+Technically, this is done by L<MooseX::MarkAsMethods>, but it's worth pointing
+out here.  Any overloads present in your class/role are marked as methods
+before autoclean is unleashed, so Everything Will Just Work as Expected.
+
 =head2 L<Try::Tiny>
 
 =head1 CAVEAT
@@ -111,7 +167,8 @@ YMMV :)
 
 =head1 SEE ALSO
 
-L<Moose>, L<Reindeer::Role>.
+L<Moose>, L<Reindeer::Role>, L<overload>.  All of the above referenced
+packages.
 
 =head1 BUGS
 
